#!/bin/bash

DEF_DIRECTORY=/opt/mvIMPACT_acquire
PRODUCT=mvGenTL-Acquire
API=mvIMPACT_acquire
TARNAME=mvGenTL_Acquire
ABI_POSTFIX=_ABI2
LINK=mvimpact-acquire
USER=$(whoami)

if [ "$1" == "-h" ] || [ "$1" == "--help" ]; then
   echo
   echo 'Installation script for the '$PRODUCT' driver.'
   echo
   echo "The default installation path is: "$DEF_DIRECTORY
   echo "Usage:		./install_mvGenTL_Acquire.sh [OPTION] ... "
   echo "Example:	./install_mvGenTL_Acquire.sh -p /myPath"
   echo 
   echo "Arguments:"
   echo "-h	--help		This help print."
   echo "-p	--path		Set the directory where the files shall be installed."
   echo
   exit
fi   

# Print out ASCII-Art Logo.
clear;
echo ""
echo ""
echo ""
echo ""
echo "                                ===     ===    .MMMO                             "
echo "                                 ==+    ==     M         ,MMM   ?M MM,           "
echo "                                 .==   .=+     M  MMM   M    M   M   M           "
echo "                                  ==+  ==.     M    M   M °°°    M   M           "
echo "             ..                   .== ,==       MMMM    'MMMM    M   M           "
echo "   MMMM   DMMMMMM      MMMMMM      =====                                         "
echo "   MMMM MMMMMMMMMMM :MMMMMMMMMM     ====          MMMMMMMMMMMM   MMM             "
echo "   MMMMMMMMMMMMMMMMMMMMMMMMMMMMM                 MMMMMMMMMMMM   MMM              "
echo "   MMMMMMM   .MMMMMMMM    MMMMMM                     MMM       MMM               "
echo "   MMMMM.      MMMMMM      MMMMM                    MM7       MMM                "
echo "   MMMMM       MMMMM       MMMMM                   MMM       IMM                 "
echo "   MMMMM       MMMMM       MMMMM                  MMM       MMMMMMMMMM           "
echo "   MMMMM       MMMMM       MMMMM                                                 "
echo "   MMMMM       MMMMM       MMMMM       M     MMM    MM    M   M  MMM  MMMM   MMMM"
echo "   MMMMM       MMMMM       MMMMM      M M   M   M  M   M  M   M   M   M   M  M   "
echo "   MMMMM       MMMMM       MMMMM     M   M  M      M   M  M   M   M   MMM,   MMM "
echo "   MMMMM       MMMMM       MMMMM     MMMMM  M   M  M  ,M  M   M   M   M   M  M   "
echo "                                     M   M  'MMM'   MMMM, 'MMM'  MMM  M   M  MMMM"
echo "==================================================================================" 
sleep 1

# Check if the user did specify that we shall use a specific directory instead of DEF_DIRECTORY
if [ "$1" == "-p" ] || [ "$1" == "--path" ] ; then
    if [ $(echo "$2") ] ; then
      DEF_DIRECTORY=$2
    else
      echo
      echo "WARNING: Path option used with no defined path, will use: $DEF_DIRECTORY directory"
    fi
else
   echo
   echo "No target directory specified, default directory: $DEF_DIRECTORY will be used..."
fi

# Get the targets plattform and if it is called "i686" we know it is a x86 system, else it s x86_64
TARGET=$(uname -m)
if [ "$TARGET" == "i686" ]; then
   TARGET="x86"
fi

# Get the sourcedir (the directory where the files for the installation are) and cd to it
# (The script file must be in the same directory as the source TGZ) !!!
if which dirname >/dev/null; then
    SCRIPTSOURCEDIR=($PWD"/"$(dirname $0))
fi
if [ "$SCRIPTSOURCEDIR" != "$PWD" ]; then
   if [ -z $SCRIPTSOURCEDIR ] || [ "$SCRIPTSOURCEDIR" == "." ]; then
      SCRIPTSOURCEDIR=$PWD
   fi
   cd $SCRIPTSOURCEDIR
fi

# Set variables for GenICam and mvIMPACT_acquire for later use
if grep -q '/etc/ld.so.conf.d/' /etc/ld.so.conf; then
   GENICAM_LDSOCONF_FILE=/etc/ld.so.conf.d/genicam.conf
   ACQUIRE_LDSOCONF_FILE=/etc/ld.so.conf.d/acquire.conf
   #sudo rm -f $GENICAM_LDSOCONF_FILE; sudo touch $GENICAM_LDSOCONF_FILE
   #sudo rm -f $ACQUIRE_LDSOCONF_FILE; sudo touch $ACQUIRE_LDSOCONF_FILE
else
   GENICAM_LDSOCONF_FILE=/etc/ld.so.conf
   ACQUIRE_LDSOCONF_FILE=/etc/ld.so.conf
fi

# Make sure the environment variables are set at the next boot as well
if grep -q '/etc/profile.d/' /etc/profile; then
   GENICAM_EXPORT_FILE=/etc/profile.d/genicam.sh
   ACQUIRE_EXPORT_FILE=/etc/profile.d/acquire.sh
   #sudo rm -f $GENICAM_EXPORT_FILE; sudo touch $GENICAM_EXPORT_FILE
   #sudo rm -f $ACQUIRE_EXPORT_FILE; sudo touch $ACQUIRE_EXPORT_FILE
else
   GENICAM_EXPORT_FILE=/etc/profile
   ACQUIRE_EXPORT_FILE=/etc/profile
fi

# Get driver name, version, file
if  ls mvGenTL_Acquire*.tgz > 0; then
  TARNAME=`ls mvGenTL_Acquire* | sed -e s/\\.tgz//`
  TARFILE=`ls mvGenTL_Acquire*.tgz`
  VERSION=`ls mvGenTL_Acquire* | sed -e s/\\mvGenTL_Acquire// | sed -e s/\\-$TARGET// | sed -e s/\\_ABI2-// | sed -e s/\\.tgz//` 
  ACT2=$API-$VERSION
  ACT=$API-$TARGET-$VERSION
fi

# Check if tarfile is correct for the system architecture
if [ "$TARGET" == "x86_64"  ]; then
  if [ "`echo $TARNAME | grep -c x86_ABI2`" != "0" ]; then
    echo "-----------------------------------------------------------------------------------"
    echo "  ABORTING: Attempt to install 32-bit drivers in a 64-bit machine!  " 
    echo "-----------------------------------------------------------------------------------"
    exit
  fi
fi
if [ "$TARGET" == "x86" ]; then
  if [ "`echo $TARNAME | grep -c x86_64_ABI2`" != "0" ]; then
    echo "-----------------------------------------------------------------------------------"
    echo "  ABORTING: Attempt to install 64-bit drivers in a 32-bit machine!  " 
    echo "-----------------------------------------------------------------------------------"
    exit
  fi
fi

YES_NO=
# Here we will ask the user if we shall start the installation process
echo
echo "-----------------------------------------------------------------------------------"
echo "Configuration:"
echo "-----------------------------------------------------------------------------------"
echo
echo "Installation for user:		"$USER " (you can change the owner of "$DEF_DIRECTORY""
echo "				with 'chown/chmod' )"
echo "Installation directory:		"$DEF_DIRECTORY
echo "Source directory:		"$SCRIPTSOURCEDIR
echo "Version:			"$VERSION
echo "Platform:			"$TARGET
echo "TAR-File:			"$TARFILE
echo
echo "ldconfig:"
echo "GenICam:			" $GENICAM_LDSOCONF_FILE
echo "mvIMPACT_acquire: 		" $ACQUIRE_LDSOCONF_FILE
echo
echo "Exports:"
echo "GenICam:			" $GENICAM_EXPORT_FILE
echo "mvIMPACT_acquire: 		" $ACQUIRE_EXPORT_FILE
echo 
echo "--------------------------------------------------------------------"
echo
echo "Do you want to continue (default is 'yes')?"
echo "Hit 'n' + <Enter> for 'no', or just <Enter> for 'yes'."
read YES_NO

# If the user is choosing no, we will abort the installation, else we will start the process.
if [ "$YES_NO" == "n" ] || [ "$YES_NO" == "N" ]; then
  echo "Quit!"
  exit
fi
 
 # First of all ask whether to dispose of the old mvIMPACT Acquire installation
echo "Do you want to remove previous installation (default is 'yes')?"
echo "This will remove mvIMPACT Acquire for ALL installed Products!!!"
echo "Hit 'n' + <Enter> for 'no', or just <Enter> for 'yes'."
read YES_NO
if [ "$YES_NO" == "n" ] || [ "$YES_NO" == "N" ]; then
  echo "Previous mvIMPACT Acquire Installation ($MVIMPACT_ACQUIRE_DIR) NOT removed!"
else
  sudo rm -rf $MVIMPACT_ACQUIRE_DIR
  if [ $? == 0 ]; then
    echo "Previous mvIMPACT Acquire Installation ($MVIMPACT_ACQUIRE_DIR) removed successfully!"
  else
    echo "Error removing previous mvIMPACT Acquire Installation ($MVIMPACT_ACQUIRE_DIR)!"
    echo "$?"
  fi
fi
 
# Create the *.conf files if the system is supporting ld.so.conf.d
if grep -q '/etc/ld.so.conf.d/' /etc/ld.so.conf; then
  sudo rm -f $GENICAM_LDSOCONF_FILE; sudo touch $GENICAM_LDSOCONF_FILE
  sudo rm -f $ACQUIRE_LDSOCONF_FILE; sudo touch $ACQUIRE_LDSOCONF_FILE
fi

# Create the export files if the system is supporting profile.d
if grep -q '/etc/profile.d/' /etc/profile; then
  sudo rm -f $GENICAM_EXPORT_FILE; sudo touch $GENICAM_EXPORT_FILE
  sudo rm -f $ACQUIRE_EXPORT_FILE; sudo touch $ACQUIRE_EXPORT_FILE
fi

# Check if the destination directory exist, else create it
if ! [ -d $DEF_DIRECTORY ]; then
  # the destination directory does not yet exist
  # first try to create it as a normal user
  mkdir -p $DEF_DIRECTORY >/dev/null 2>&1
  if ! [ -d $DEF_DIRECTORY ]; then
    # that didn't work
    # now try it as superuser
    sudo mkdir -p $DEF_DIRECTORY
  fi
  if ! [ -d $DEF_DIRECTORY  ]; then
    echo 'ERROR: Could not create target directory' $DEF_DIRECTORY '.'
    echo 'Problem:'$?
    echo 'Maybe you specified a partition that was mounted read only?'
    echo
    exit
  fi
else
  echo 'Installation directory already exists.'
fi


# in case the directory already existed BUT it belongs to other user
sudo chown -R $USER:$USER $DEF_DIRECTORY

# Check the actual tarfile
if ! [ -r $TARFILE ]; then
  echo 'ERROR: could not read' $TARFILE.
  echo
  exit
fi

# needed at compile time (used during development, but not shipped with the final program)
ACT=$API-$VERSION.tar

# needed at run time
BC=mvGenTL_Acquire_runtime
BCT=$BC-$VERSION.tar

# Now unpack the tarfile into /tmp
cd /tmp
tar xfz $SCRIPTSOURCEDIR/$TARFILE

# Change to destination directory and remove older libs if any
cd $DEF_DIRECTORY
if ! [ -d $DEF_DIRECTORY/runtime ]; then
  mkdir runtime
  if ! [ -d $DEF_DIRECTORY/runtime ]; then
      # that didn't work
      # now try it as superuser
      sudo mkdir --parent $DEF_DIRECTORY/runtime
  fi
fi
cd runtime
# remove older versions (if any)
sudo rm -f lib/libmv*.so*

# Now unpack the mvBlueCOUGAR_runtime files
sudo tar xf /tmp/$BCT

# the runtime tar contains either the i86 or the x64 tgz
if [ -r GenICam_Runtime_gcc40_Linux32_i86_v*.tgz ]; then
   sudo tar xfz GenICam_Runtime_gcc40_Linux32_i86_v*.tgz;
   if [ x$TARGET != xx86 ]; then
      echo 'Platform conflict : GenICam runtime is 32bit, but target is 64bit'
   fi
fi
if [ -r GenICam_Runtime_gcc40_Linux64_x64_v*.tgz ]; then
   sudo tar xfz GenICam_Runtime_gcc40_Linux64_x64_v*.tgz;
   if [ x$TARGET = xx86 ]; then
      echo 'Platform conflict : GenICam runtime is 64bit, but target is 32bit'
   fi
fi

sudo chown -R $(whoami):$(whoami) xml log licenses bin License_ReadMe.txt

if [ x$TARGET == xx86 ]; then
	GENVER=`echo GenICam_Runtime_gcc40_Linux32_i86_v*.tgz | sed -e s/GenICam_Runtime_gcc40_Linux32_i86_v// | sed -e s/\\.tgz// | sed -e 's/.\{2\}$//'`
else
	GENVER=`echo GenICam_Runtime_gcc40_Linux64_x64_v*.tgz | sed -e s/GenICam_Runtime_gcc40_Linux64_x64_v// | sed -e s/\\.tgz// | sed -e 's/.\{2\}$//'`
fi

if ! [ -r $GENICAM_EXPORT_FILE ]; then
   echo 'Error : cannot write to' $GENICAM_EXPORT_FILE.
   echo 'After the next boot, the required environment variables will not be set.'
   echo
else
   # tests below do not yet check for *commented out* export lines
   if grep -q 'GENICAM_ROOT=' $GENICAM_EXPORT_FILE; then
      echo 'GENICAM_ROOT already defined in' $GENICAM_EXPORT_FILE.
   else
      sudo sh -c "echo 'export GENICAM_ROOT=$DEF_DIRECTORY/runtime' >> $GENICAM_EXPORT_FILE"
   fi
   if grep -q 'GENICAM_ROOT_V$GENVER=' $GENICAM_EXPORT_FILE; then
      echo 'GENICAM_ROOT_V'$GENVER' already defined in' $GENICAM_EXPORT_FILE.
   else
      sudo sh -c "echo 'export GENICAM_ROOT_V$GENVER=$DEF_DIRECTORY/runtime' >> $GENICAM_EXPORT_FILE"
   fi
   if [ x$TARGET = xx86 ]; then
      if grep -q 'GENICAM_GENTL32_PATH=' $GENICAM_EXPORT_FILE; then
         echo 'GENICAM_GENTL32_PATH already defined in' $GENICAM_EXPORT_FILE.
      else
         sudo sh -c "echo 'if [ x\$GENICAM_GENTL32_PATH == x ]; then
   export GENICAM_GENTL32_PATH=$DEF_DIRECTORY/runtime/lib
elif [ x\$GENICAM_GENTL32_PATH != x$DEF_DIRECTORY/runtime/lib ]; then
   if ! \$(echo \$GENICAM_GENTL32_PATH | grep -q \":$DEF_DIRECTORY/runtime/lib\"); then
      export GENICAM_GENTL32_PATH=\$GENICAM_GENTL32_PATH:$DEF_DIRECTORY/runtime/lib
   fi
fi' >> $GENICAM_EXPORT_FILE"
      fi
   else
      if grep -q 'GENICAM_GENTL64_PATH=' $GENICAM_EXPORT_FILE; then
         echo 'GENICAM_GENTL64_PATH already defined in' $GENICAM_EXPORT_FILE.
      else
         sudo sh -c "echo 'if [ x\$GENICAM_GENTL64_PATH == x ]; then
   export GENICAM_GENTL64_PATH=$DEF_DIRECTORY/runtime/lib
elif [ x\$GENICAM_GENTL64_PATH != x$DEF_DIRECTORY/runtime/lib ]; then
   if ! \$(echo \$GENICAM_GENTL64_PATH | grep -q \":$DEF_DIRECTORY/runtime/lib\"); then
      export GENICAM_GENTL64_PATH=\$GENICAM_GENTL64_PATH:$DEF_DIRECTORY/runtime/lib
   fi
fi' >> $GENICAM_EXPORT_FILE"
      fi
   fi
   if grep -q 'GENICAM_CACHE_V'$GENVER'=' $GENICAM_EXPORT_FILE; then
      echo 'GENICAM_CACHE_V'$GENVER' already defined in' $GENICAM_EXPORT_FILE.
   else
      sudo sh -c "echo 'export GENICAM_CACHE_V$GENVER=/tmp' >> $GENICAM_EXPORT_FILE"
   fi
   if grep -q 'GENICAM_LOG_CONFIG_V'$GENVER'=' $GENICAM_EXPORT_FILE; then
      echo 'GENICAM_LOG_CONFIG_V'$GENVER' already defined in' $GENICAM_EXPORT_FILE.
   else
      sudo sh -c "echo 'export GENICAM_LOG_CONFIG_V'$GENVER'=$DEF_DIRECTORY/runtime/log/config-unix/DefaultLogging.properties' >> $GENICAM_EXPORT_FILE"
   fi
fi

# Now check if we can unpack the tar file with the device independent stuff
# this is entirely optional
if [ -r /tmp/$ACT ]; then
   cd /tmp
   tar xf /tmp/$ACT
   sudo cp -r $ACT2/* $DEF_DIRECTORY
   cd $DEF_DIRECTORY
   if grep -q 'MVIMPACT_ACQUIRE_DIR=' $ACQUIRE_EXPORT_FILE; then
      echo 'MVIMPACT_ACQUIRE_DIR already defined in' $ACQUIRE_EXPORT_FILE.
   else
      sudo sh -c "echo 'export MVIMPACT_ACQUIRE_DIR=$DEF_DIRECTORY' >> $ACQUIRE_EXPORT_FILE"
   fi

   if grep -q "$DEF_DIRECTORY/lib/$TARGET" $ACQUIRE_LDSOCONF_FILE; then
      echo "$DEF_DIRECTORY/lib/$TARGET already defined in" $ACQUIRE_LDSOCONF_FILE.
   else
      sudo sh -c "echo '$DEF_DIRECTORY/lib/$TARGET' >> $ACQUIRE_LDSOCONF_FILE"
   fi
else
  echo
  echo "ERROR: Could not read: /tmp/"$ACT2
  exit
fi

# now do the shared linker setup
if ! [ -r $GENICAM_LDSOCONF_FILE ]; then
   echo 'Error : cannot write to' $GENICAM_LDSOCONF_FILE.
   echo 'Execution will fail, as at run time, the shared objects will not be found.'
   echo
else
   if [ x$TARGET = xx86 ]; then
      GENILIBPATH=Linux32_i86
   else
      GENILIBPATH=Linux64_x64
   fi
   # tests below do not check for *commented out* link lines
   # must later add substring check

   # acquire libs
   if grep -q "$DEF_DIRECTORY/runtime/lib" $GENICAM_LDSOCONF_FILE; then
      echo "$DEF_DIRECTORY/runtime/lib already defined in" $GENICAM_LDSOCONF_FILE.
   else
      sudo sh -c "echo '$DEF_DIRECTORY/runtime/lib' >> $GENICAM_LDSOCONF_FILE"
   fi

   # genicam libs
   if grep -q "$DEF_DIRECTORY/runtime/bin/$GENILIBPATH" $GENICAM_LDSOCONF_FILE; then
      echo "$DEF_DIRECTORY/runtime/bin/$GENILIBPATH already defined in" $GENICAM_LDSOCONF_FILE.
   else
      sudo sh -c "echo '$DEF_DIRECTORY/runtime/bin/$GENILIBPATH' >> $GENICAM_LDSOCONF_FILE"
   fi
   if grep -q "$DEF_DIRECTORY/runtime/bin/$GENILIBPATH/GenApi/Generic" $GENICAM_LDSOCONF_FILE; then
      echo "$DEF_DIRECTORY/runtime/bin/$GENILIBPATH/GenApi/Generic already defined in" $GENICAM_LDSOCONF_FILE.
   else
      sudo sh -c "echo '$DEF_DIRECTORY/runtime/bin/$GENILIBPATH/GenApi/Generic' >> $GENICAM_LDSOCONF_FILE"
   fi
fi


# This variable must be exported, or else wxPropView-related make problems can arise (wxPropGrid cannot be found)
export MVIMPACT_ACQUIRE_DIR=$DEF_DIRECTORY

# Set the libs to ldconfig
sudo /sbin/ldconfig

cd $DEF_DIRECTORY/runtime/lib
ln -fs libmvGenTLProducer.so mvGenTLProducer.cti >/dev/null 2>&1
if ! [ -e mvGenTLProducer.cti ]; then
   sudo ln -fs libmvGenTLProducer.so mvGenTLProducer.cti
fi
# This lib is the deprecated version of mvGenTLProducer. Rigth now this is kept for backward compatibility only
ln -fs libmvTLIClientGigE.so mvTLIClientGigE.cti >/dev/null 2>&1
if ! [ -e mvTLIClientGigE.cti ]; then
   sudo ln -fs libmvTLIClientGigE.so mvTLIClientGigE.cti
fi

if [ -r /tmp/$ACT ]; then
   # the shared libs are part of the runtime tree, but the Makefile expects
   # them in the development tree, so we add links here
   # this must be done after ldconfig, so we can link to simple *.so files
   cd $DEF_DIRECTORY/lib/$TARGET
   for a in $DEF_DIRECTORY/runtime/lib/libmv*.so; do
      ln -f -s $a . >/dev/null 2>&1
   done
fi

# Clen up /tmp
rm -r -f /tmp/$ACT /tmp/$BCT /tmp/$API-$VERSION

# install needed libraries and compiler
COULD_NOT_INSTALL="Could not find apt-get or yast; please install >%s< manually."

# check if we have g++
if ! which g++ >/dev/null 2>&1; then
   if which apt-get >/dev/null 2>&1; then
      sudo apt-get -q install g++
   elif sudo which yast >/dev/null 2>&1; then
      YASTBIN=`sudo which yast`
      sudo $YASTBIN --install gcc-c++
   else
      printf "$COULD_NOT_INSTALL" "g++"
   fi
fi

# check if we have libexpat
if which apt-get >/dev/null 2>&1; then
  sudo apt-get -q install libexpat1-dev
elif sudo which yast >/dev/null 2>&1; then
  YASTBIN=`sudo which yast`
  sudo $YASTBIN --install expat libexpat-devel
else
  printf "$COULD_NOT_INSTALL" "libexpat"
fi

INPUT_REQUEST="Do you want to install >%s< (default is 'yes')?\nHit 'n' + <Enter> for 'no', or just <Enter> for 'yes'.\n"
YES_NO=

# do we want to install wxWidgets?
if ! which wx-config >/dev/null 2>&1; then
   echo
   printf "$INPUT_REQUEST" "wxWidgets"
   echo "This is highly recommended, as without wxWidgets, you cannot build wxPropView."
   echo
   read YES_NO
   if [ "$YES_NO" == "n" ] || [ "$YES_NO" == "N" ]; then
      echo 'Not installing wxWidgets'
   else
      if which apt-get >/dev/null 2>&1; then
         echo 'Installing wxWidgets'
         sudo apt-get -q install libwxgtk2.8-dev libwxbase2.8-0 libwxbase2.8-dev libwxgtk2.8-0 wx2.8-headers build-essential libgtk2.0-dev
      elif sudo which yast >/dev/null 2>&1; then
         echo 'Installing wxWidgets'
         YASTBIN=`sudo which yast`
         sudo $YASTBIN --install wxGTK-devel
      else
         printf "$COULD_NOT_INSTALL" "wxWidgets"
      fi
   fi
fi

# do we want to install FLTK?
if ! which fltk-config >/dev/null 2>&1; then
   echo
   printf "$INPUT_REQUEST" "FLTK"
   echo "This is only required if you want to build the 'LiveSnapFLTK' sample."
   echo
   read YES_NO
   if [ "$YES_NO" == "n" ] || [ "$YES_NO" == "N" ]; then
      echo 'Not installing FLTK'
   else
      if which apt-get >/dev/null 2>&1; then
         echo 'Installing FLTK'
         sudo apt-get -q install libgl1-mesa-dev
         sudo apt-get -q install libfltk1.1-dev
      elif sudo which yast >/dev/null 2>&1; then
         echo 'Installing FLTK'
         YASTBIN=`sudo which yast`
         sudo $YASTBIN --install Mesa-devel
         sudo $YASTBIN --install fltk-devel
      else
         printf "$COULD_NOT_INSTALL" "FLTK"
      fi
   fi
fi

echo
echo "Do you want the tools and samples to be built (default is 'yes')?"
echo "Hit 'n' + <Enter> for 'no', or just <Enter> for 'yes'."
read YES_NO
if [ "$YES_NO" == "n" ] || [ "$YES_NO" == "N" ]; then
   echo
   echo 'The tools and samples were not built.'
   echo 'To build them yourself, type:'
   echo '  cd ~/mvimpact-acquire'
   echo "  make $TARGET"
   echo '  sudo /sbin/ldconfig'
else
   cd $DEF_DIRECTORY
   sudo chown -R $USER $DEF_DIRECTORY
   make $TARGET
   sudo /sbin/ldconfig

   # Shall the MV Tools be linked in /usr/bin?
   echo "Do you want to set a link to /usr/bin for wxPropView, mvIPConfigure and mvDeviceConfigure (default is 'yes')?"
   echo "Hit 'n' + <Enter> for 'no', or just <Enter> for 'yes'."
   read YES_NO
   if [ "$YES_NO" == "n" ] || [ "$YES_NO" == "N" ]; then
      echo "Will not set any new link to /usr/bin."
   else
      if [ -r /usr/bin ]; then
	 # Set wxPropView
	 if [ -r $DEF_DIRECTORY/apps/mvPropView/$TARGET/wxPropView ]; then
            sudo rm -f /usr/bin/wxPropView
            sudo ln -s $DEF_DIRECTORY/apps/mvPropView/$TARGET/wxPropView /usr/bin/wxPropView
         fi
	 # Set mvIPConfigure
	 if [ -r $DEF_DIRECTORY/apps/mvIPConfigure/$TARGET/mvIPConfigure ]; then
            sudo rm -f /usr/bin/mvIPConfigure
            sudo ln -s $DEF_DIRECTORY/apps/mvIPConfigure/$TARGET/mvIPConfigure /usr/bin/mvIPConfigure
         fi
	 # Set mvDeviceConfigure
	 if [ -r $DEF_DIRECTORY/apps/mvDeviceConfigure/$TARGET/mvDeviceConfigure ]; then
            sudo rm -f /usr/bin/mvDeviceConfigure
            sudo ln -s $DEF_DIRECTORY/apps/mvDeviceConfigure/$TARGET/mvDeviceConfigure /usr/bin/mvDeviceConfigure
         fi
      fi
   fi
fi

source $GENICAM_EXPORT_FILE
echo
echo "-----------------------------------------------------------------------------------"
echo "                            Installation successful!                               "
echo "-----------------------------------------------------------------------------------"
echo

echo 'If the device is not initilising execute the following commands:'
echo '  ' export GENICAM_ROOT=$1
echo '  ' export "GENICAM_ROOT_V$GENVER="$DEF_DIRECTORY/runtime
if [ x$TARGET = xx86 ]; then
   echo '  ' export GENICAM_GENTL32_PATH=$DEF_DIRECTORY/runtime/lib
else
   echo '  ' export GENICAM_GENTL64_PATH=$DEF_DIRECTORY/runtime/lib
fi
echo '  ' export "GENICAM_CACHE_V$GENVER="/tmp
echo '  ' export "GENICAM_LOG_CONFIG_V$GENVER="$DEF_DIRECTORY/runtime/log/config-unix/DefaultLogging.properties
echo 'or source' $GENICAM_EXPORT_FILE:
echo '  ' . $GENICAM_EXPORT_FILE
echo 'or restart X11 (Ctrl-Alt-Backspace (twice on OpenSuSE)).'
echo '(The exports above have been added to' $GENICAM_EXPORT_FILE.
echo ' This file is read when you log in, which is normally done when starting X11.)'
echo